@@ -21,6 +21,13 @@
  * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA
  * 02110-1335, USA.
  */
+
+/**
+ * SECTION:meta-shadow-factory
+ * @title: MetaShadowFactory
+ * @short_description: Create and cache shadow textures for arbitrary window shapes
+ */
+
 #include <config.h>
 #include <math.h>
 #include <string.h>
@@ -119,7 +126,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 /* The first element in this array also defines the default parameters
  * for newly created classes */
-MetaShadowClassInfo default_shadow_classes[] = {
+static MetaShadowClassInfo default_shadow_classes[] = {
   { "normal",       { 6, -1, 0, 3, 255 }, { 3, -1, 0, 3, 128 } },
   { "dialog",       { 6, -1, 0, 3, 255 }, { 3, -1, 0, 3, 128 } },
   { "modal_dialog", { 6, -1, 0, 1, 255 }, { 3, -1, 0, 3, 128 } },
@@ -130,7 +137,7 @@ MetaShadowClassInfo default_shadow_classes[] = {
   { "popup-menu",    { 1, -1, 0, 1, 128 }, { 1, -1, 0, 1, 128 } },
 
   { "dropdown-menu", { 1, 10, 0, 1, 128 }, { 1, 10, 0, 1, 128 } },
-  { "attached",      { 2, 50, 0, 1, 255 }, { 1, 50, 0, 1, 128 } }
+  { "attached",      { 6, -1, 0, 1, 255 }, { 3, -1, 0, 3, 128 } }
 };
 
 G_DEFINE_TYPE (MetaShadowFactory, meta_shadow_factory, G_TYPE_OBJECT);
@@ -154,7 +161,7 @@ meta_shadow_cache_key_equal (gconstpointer a,
           meta_window_shape_equal (key_a->shape, key_b->shape));
 }
 
-MetaShadow *
+LOCAL_SYMBOL MetaShadow *
 meta_shadow_ref (MetaShadow *shadow)
 {
   shadow->ref_count++;
@@ -162,7 +169,7 @@ meta_shadow_ref (MetaShadow *shadow)
   return shadow;
 }
 
-void
+LOCAL_SYMBOL void
 meta_shadow_unref (MetaShadow *shadow)
 {
   shadow->ref_count--;
@@ -199,7 +206,7 @@ meta_shadow_unref (MetaShadow *shadow)
  * different sizes with the same extracted #MetaWindowShape the
  * size needs to be passed in here.)
  */
-void
+LOCAL_SYMBOL void
 meta_shadow_paint (MetaShadow     *shadow,
                    int             window_x,
                    int             window_y,
@@ -362,7 +369,7 @@ meta_shadow_paint (MetaShadow     *shadow,
  * Computes the bounds of the pixels that will be affected by
  * meta_shadow_paint()
  */
-void
+LOCAL_SYMBOL void
 meta_shadow_get_bounds  (MetaShadow            *shadow,
                          int                    window_x,
                          int                    window_y,
@@ -446,7 +453,7 @@ meta_shadow_factory_class_init (MetaShadowFactoryClass *klass)
                   G_TYPE_NONE, 0);
 }
 
-MetaShadowFactory *
+LOCAL_SYMBOL MetaShadowFactory *
 meta_shadow_factory_new (void)
 {
   return g_object_new (META_TYPE_SHADOW_FACTORY, NULL);
@@ -787,15 +794,15 @@ make_shadow (MetaShadow     *shadow,
    * in the case of top_fade >= 0. We also account for padding at the left for symmetry
    * though that doesn't currently occur.
    */
-  shadow->texture = cogl_texture_new_from_data (shadow->outer_border_left + extents.width + shadow->outer_border_right,
-                                                shadow->outer_border_top + extents.height + shadow->outer_border_bottom,
-                                                COGL_TEXTURE_NONE,
-                                                COGL_PIXEL_FORMAT_A_8,
-                                                COGL_PIXEL_FORMAT_ANY,
-                                                buffer_width,
-                                                (buffer +
-                                                 (y_offset - shadow->outer_border_top) * buffer_width +
-                                                 (x_offset - shadow->outer_border_left)));
+  shadow->texture = meta_cogl_texture_new_from_data_wrapper (shadow->outer_border_left + extents.width + shadow->outer_border_right,
+                                                             shadow->outer_border_top + extents.height + shadow->outer_border_bottom,
+                                                             COGL_TEXTURE_NONE,
+                                                             COGL_PIXEL_FORMAT_A_8,
+                                                             COGL_PIXEL_FORMAT_ANY,
+                                                             buffer_width,
+                                                             (buffer +
+                                                              (y_offset - shadow->outer_border_top) * buffer_width +
+                                                              (x_offset - shadow->outer_border_left)));
 
   cairo_region_destroy (row_convolve_region);
   cairo_region_destroy (column_convolve_region);
@@ -853,7 +860,7 @@ get_shadow_params (MetaShadowFactory *factory,
  * Return value: (transfer full): a newly referenced #MetaShadow; unref with
  *  meta_shadow_unref()
  */
-MetaShadow *
+LOCAL_SYMBOL MetaShadow *
 meta_shadow_factory_get_shadow (MetaShadowFactory *factory,
                                 MetaWindowShape   *shape,
                                 int                width,
