@@ -41,9 +41,9 @@
  * meta_core_get_window_info() which takes a bunch of pointers to variables
  * to put its results in, and only fills in the non-null ones.
  */
-static MetaWindow *
-get_window (Display *xdisplay,
-            Window   frame_xwindow)
+LOCAL_SYMBOL MetaWindow *
+meta_core_get_window (Display *xdisplay,
+                      Window   frame_xwindow)
 {
   MetaDisplay *display;
   MetaWindow *window;
@@ -89,6 +89,7 @@ meta_core_get (Display *xdisplay,
   if (request != META_CORE_WINDOW_HAS_FRAME &&
       (window == NULL || window->frame == NULL)) {
     meta_bug ("No such frame window 0x%lx!\n", xwindow);
+    va_end (args);
     return;
   }
 
@@ -167,7 +168,7 @@ LOCAL_SYMBOL void
 meta_core_queue_frame_resize (Display *xdisplay,
                               Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_queue (window, META_QUEUE_MOVE_RESIZE);
 }
@@ -178,7 +179,7 @@ meta_core_user_move (Display *xdisplay,
                      int      x,
                      int      y)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_move (window, TRUE, x, y);
 }
@@ -190,7 +191,7 @@ meta_core_user_resize  (Display *xdisplay,
                         int      width,
                         int      height)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_resize_with_gravity (window, TRUE, width, height, gravity);
 }
@@ -199,7 +200,7 @@ LOCAL_SYMBOL void
 meta_core_user_raise (Display *xdisplay,
                       Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
   
   meta_window_raise (window);
 }
@@ -247,7 +248,7 @@ meta_core_user_lower_and_unfocus (Display *xdisplay,
                                   Window   frame_xwindow,
                                   guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -332,7 +333,7 @@ meta_core_user_focus (Display *xdisplay,
                       Window   frame_xwindow,
                       guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
   
   meta_window_focus (window, timestamp);
 }
@@ -341,7 +342,7 @@ LOCAL_SYMBOL void
 meta_core_minimize (Display *xdisplay,
                     Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -352,7 +353,7 @@ LOCAL_SYMBOL void
 meta_core_maximize (Display *xdisplay,
                     Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -367,7 +368,7 @@ LOCAL_SYMBOL void
 meta_core_toggle_maximize_vertically (Display *xdisplay,
 				      Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -386,7 +387,7 @@ LOCAL_SYMBOL void
 meta_core_toggle_maximize_horizontally (Display *xdisplay,
 				        Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -405,7 +406,7 @@ LOCAL_SYMBOL void
 meta_core_toggle_maximize (Display *xdisplay,
                            Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -424,7 +425,7 @@ LOCAL_SYMBOL void
 meta_core_unmaximize (Display *xdisplay,
                       Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   if (meta_prefs_get_raise_on_click ())
     meta_window_raise (window);
@@ -438,7 +439,7 @@ meta_core_delete (Display *xdisplay,
                   Window   frame_xwindow,
                   guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
      
   meta_window_delete (window, timestamp);
 }
@@ -448,7 +449,7 @@ meta_core_unshade (Display *xdisplay,
                    Window   frame_xwindow,
                    guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -460,7 +461,7 @@ meta_core_shade (Display *xdisplay,
                  Window   frame_xwindow,
                  guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
   
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -471,7 +472,7 @@ LOCAL_SYMBOL void
 meta_core_unstick (Display *xdisplay,
                    Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_unstick (window);
 }
@@ -480,7 +481,7 @@ LOCAL_SYMBOL void
 meta_core_make_above (Display *xdisplay,
                       Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_make_above (window);
 }
@@ -489,7 +490,7 @@ LOCAL_SYMBOL void
 meta_core_unmake_above (Display *xdisplay,
                         Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_unmake_above (window);
 }
@@ -499,7 +500,7 @@ meta_core_adjust_opacity      (Display *xdisplay,
                                Window   frame_xwindow,
                                gboolean increase)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_adjust_opacity (window, increase);
 }
@@ -508,7 +509,7 @@ LOCAL_SYMBOL void
 meta_core_stick (Display *xdisplay,
                  Window   frame_xwindow)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_stick (window);
 }
@@ -518,7 +519,7 @@ meta_core_change_workspace (Display *xdisplay,
                             Window   frame_xwindow,
                             int      new_workspace)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_change_workspace (window,
                                 meta_screen_get_workspace_by_index (window->screen,
@@ -553,7 +554,7 @@ meta_core_show_window_menu (Display *xdisplay,
                             int      button,
                             guint32  timestamp)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_screen_hide_hud_and_preview (window->screen);
 
@@ -662,6 +663,9 @@ meta_core_get_menu_accelerator (MetaMenuOp           menu_op,
     case META_MENU_OP_MOVE_DOWN:
       name = "move-to-workspace-down";
       break;
+    case META_MENU_OP_MOVE_NEW:
+      name = "move-to-workspace-new";
+      break;
     case META_MENU_OP_RECOVER:
       /* No keybinding for this one */
       break;
@@ -706,7 +710,7 @@ meta_core_begin_grab_op (Display    *xdisplay,
                          int         root_x,
                          int         root_y)
 {
-  MetaWindow *window = get_window (xdisplay, frame_xwindow);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
   MetaDisplay *display;
   MetaScreen *screen;
   
@@ -794,7 +798,7 @@ meta_core_set_screen_cursor (Display *xdisplay,
                              Window   frame_on_screen,
                              MetaCursor cursor)
 {
-  MetaWindow *window = get_window (xdisplay, frame_on_screen);
+  MetaWindow *window = meta_core_get_window (xdisplay, frame_on_screen);
 
   meta_frame_set_screen_cursor (window->frame, cursor);
 }
