@@ -25,7 +25,6 @@
 
 #include <config.h>
 #include "frame.h"
-#include "bell.h"
 #include <meta/errors.h>
 #include "keybindings-private.h"
 
@@ -66,7 +65,6 @@ meta_window_ensure_frame (MetaWindow *window)
   frame->right_width = 0;
   frame->current_cursor = 0;
 
-  frame->mapped = FALSE;
   frame->is_flashing = FALSE;
   
   meta_verbose ("Framing window %s: visual %s default, depth %d default depth %d\n",
@@ -156,7 +154,6 @@ meta_window_ensure_frame (MetaWindow *window)
    * style and background.
    */
   meta_ui_update_frame_style (window->screen->ui, frame->xwindow);
-  meta_ui_reset_frame_bg (window->screen->ui, frame->xwindow);
   
   if (window->title)
     meta_ui_set_frame_title (window->screen->ui,
@@ -166,6 +163,8 @@ meta_window_ensure_frame (MetaWindow *window)
   /* Move keybindings to frame instead of window */
   meta_window_grab_keys (window);
 
+  meta_ui_map_frame (frame->window->screen->ui, frame->xwindow);
+
   meta_display_ungrab (window->display);
 }
 
@@ -183,9 +182,7 @@ meta_window_destroy_frame (MetaWindow *window)
   frame = window->frame;
 
   meta_frame_calc_borders (frame, &borders);
-  
-  meta_bell_notify_frame_destroy (frame);
-  
+
   /* Unparent the client window; it may be destroyed,
    * thus the error trap.
    */
@@ -276,6 +273,18 @@ meta_frame_get_flags (MetaFrame *frame)
   if (META_WINDOW_ALLOWS_VERTICAL_RESIZE (frame->window))
     flags |= META_FRAME_ALLOWS_VERTICAL_RESIZE;
   
+  if (META_WINDOW_ALLOWS_TOP_RESIZE (frame->window))
+    flags |= META_FRAME_ALLOWS_TOP_RESIZE;
+
+  if (META_WINDOW_ALLOWS_BOTTOM_RESIZE (frame->window))
+    flags |= META_FRAME_ALLOWS_BOTTOM_RESIZE;
+
+  if (META_WINDOW_ALLOWS_LEFT_RESIZE (frame->window))
+    flags |= META_FRAME_ALLOWS_LEFT_RESIZE;
+
+  if (META_WINDOW_ALLOWS_RIGHT_RESIZE (frame->window))
+    flags |= META_FRAME_ALLOWS_RIGHT_RESIZE;
+
   if (meta_window_appears_focused (frame->window))
     flags |= META_FRAME_HAS_FOCUS;
 
@@ -291,12 +300,21 @@ meta_frame_get_flags (MetaFrame *frame)
   if (META_WINDOW_MAXIMIZED (frame->window))
     flags |= META_FRAME_MAXIMIZED;
 
-  if (META_WINDOW_TILED_LEFT (frame->window))
+  if (META_WINDOW_TILED_LEFT (frame->window) ||
+      META_WINDOW_TILED_ULC (frame->window) ||
+      META_WINDOW_TILED_LLC (frame->window))
     flags |= META_FRAME_TILED_LEFT;
 
-  if (META_WINDOW_TILED_RIGHT (frame->window))
+  if (META_WINDOW_TILED_RIGHT (frame->window) ||
+      META_WINDOW_TILED_URC (frame->window) ||
+      META_WINDOW_TILED_LRC (frame->window))
     flags |= META_FRAME_TILED_RIGHT;
 
+  if (META_WINDOW_TILED_TOP (frame->window) ||
+      META_WINDOW_TILED_BOTTOM (frame->window)) {
+    flags |= META_FRAME_MAXIMIZED;
+  }
+
   if (frame->window->fullscreen)
     flags |= META_FRAME_FULLSCREEN;
 
@@ -305,7 +323,7 @@ meta_frame_get_flags (MetaFrame *frame)
 
   if (frame->window->wm_state_above)
     flags |= META_FRAME_ABOVE;
-  
+
   return flags;
 }
 
@@ -358,15 +376,6 @@ meta_frame_sync_to_window (MetaFrame *frame,
               frame->rect.x + frame->rect.width,
               frame->rect.y + frame->rect.height);
 
-  /* set bg to none to avoid flicker */
-  if (need_resize)
-    {
-      meta_ui_unflicker_frame_bg (frame->window->screen->ui,
-                                  frame->xwindow,
-                                  frame->rect.width,
-                                  frame->rect.height);
-    }
-
   meta_ui_move_resize_frame (frame->window->screen->ui,
 			     frame->xwindow,
 			     frame->rect.x,
@@ -376,9 +385,6 @@ meta_frame_sync_to_window (MetaFrame *frame,
 
   if (need_resize)
     {
-      meta_ui_reset_frame_bg (frame->window->screen->ui,
-                              frame->xwindow);
-
       /* If we're interactively resizing the frame, repaint
        * it immediately so we don't start to lag.
        */
