@@ -95,6 +95,19 @@ enum {
 #define HUD_WIDTH 24
 #define CSD_TITLEBAR_HEIGHT 48
 
+typedef enum {
+  _NET_WM_BYPASS_COMPOSITOR_HINT_AUTO = 0,
+  _NET_WM_BYPASS_COMPOSITOR_HINT_ON = 1,
+  _NET_WM_BYPASS_COMPOSITOR_HINT_OFF = 2,
+} MetaBypassCompositorHintValue;
+
+typedef enum
+{
+  META_EDGE_CONSTRAINT_NONE    = 0,
+  META_EDGE_CONSTRAINT_WINDOW  = 1,
+  META_EDGE_CONSTRAINT_MONITOR = 2,
+} MetaEdgeConstraint;
+
 struct _MetaWindow
 {
   GObject parent_instance;
@@ -113,6 +126,13 @@ struct _MetaWindow
   char *title;
 
   char *icon_name;
+
+/* XAppGtkWindow */
+  char *theme_icon_name;
+  guint progress;
+  guint progress_pulse : 1;
+/* /XappGtkWindow */
+
   GdkPixbuf *icon;
   GdkPixbuf *mini_icon;
   MetaIconCache icon_cache;
@@ -189,6 +209,12 @@ struct _MetaWindow
   guint saved_maximize : 1;
   int tile_monitor_number;
 
+  /* 0 - top
+   * 1 - right
+   * 2 - bottom
+   * 3 - left */
+  MetaEdgeConstraint edge_constraints[4];
+
   /* Whether we're shaded */
   guint shaded : 1;
 
@@ -480,8 +506,7 @@ struct _MetaWindow
   MetaWindow *tile_match;
 
   /* Bypass compositor hints */
-  guint bypass_compositor : 1;
-  guint dont_bypass_compositor : 1;
+  guint bypass_compositor;
 };
 
 struct _MetaWindowClass
@@ -578,10 +603,6 @@ void        meta_window_unshade            (MetaWindow  *window,
                                             guint32      timestamp);
 void        meta_window_adjust_opacity     (MetaWindow  *window,
                                             gboolean     increase);
-void        meta_window_change_workspace   (MetaWindow  *window,
-                                            MetaWorkspace *workspace);
-void        meta_window_stick              (MetaWindow  *window);
-void        meta_window_unstick            (MetaWindow  *window);
 
 void        meta_window_make_fullscreen_internal (MetaWindow    *window);
 void        meta_window_make_fullscreen    (MetaWindow  *window);
@@ -593,14 +614,6 @@ void        meta_window_update_fullscreen_monitors (MetaWindow    *window,
                                                     unsigned long  right);
 
 /* args to move are window pos, not frame pos */
-void        meta_window_move               (MetaWindow  *window,
-                                            gboolean     user_op,
-                                            int          root_x_nw,
-                                            int          root_y_nw);
-void        meta_window_resize             (MetaWindow  *window,
-                                            gboolean     user_op,
-                                            int          w,
-                                            int          h);
 void        meta_window_move_resize        (MetaWindow  *window,
                                             gboolean     user_op,
                                             int          root_x_nw,
