@@ -240,6 +240,85 @@ reload_wm_client_machine (MetaWindow    *window,
                 window->wm_client_machine ? window->wm_client_machine : "unset");
 }
 
+static void
+reload_theme_icon_name (MetaWindow    *window,
+                        MetaPropValue *value,
+                        gboolean       initial)
+{
+  g_free (window->theme_icon_name);
+  window->theme_icon_name = NULL;
+
+  if (value->type != META_PROP_VALUE_INVALID)
+    window->theme_icon_name = g_strdup (value->v.str);
+
+  meta_verbose ("Window theme icon name or path is \"%s\"\n",
+                window->theme_icon_name ? window->theme_icon_name : "unset");
+}
+
+static void
+reload_progress (MetaWindow    *window,
+                 MetaPropValue *value,
+                 gboolean       initial)
+{
+  if (value->type != META_PROP_VALUE_INVALID)
+    {
+      if (window->progress != value->v.cardinal)
+        {
+          window->progress = value->v.cardinal;
+          g_object_notify (window, "progress");
+
+          meta_topic (META_DEBUG_WINDOW_STATE,
+                      "Read XAppGtkWindow progress prop %u for %s\n",
+                      window->progress, window->desc);
+        }
+    }
+  else
+    {
+      if (window->progress != 0)
+        {
+          window->progress = 0;
+          g_object_notify (window, "progress");
+
+          meta_topic (META_DEBUG_WINDOW_STATE,
+                      "Read XAppGtkWindow progress prop %u for %s\n",
+                      window->progress, window->desc);
+        }
+    }
+}
+
+static void
+reload_progress_pulse (MetaWindow    *window,
+                       MetaPropValue *value,
+                       gboolean       initial)
+{
+  if (value->type != META_PROP_VALUE_INVALID)
+    {
+      gboolean new_val = value->v.cardinal == 1;
+
+      if (window->progress_pulse != new_val)
+        {
+          window->progress_pulse = new_val;
+          g_object_notify (window, "progress-pulse");
+
+          meta_topic (META_DEBUG_WINDOW_STATE,
+                      "Read XAppGtkWindow progress-pulse prop %s for %s\n",
+                      window->progress_pulse ? "TRUE" : "FALSE", window->desc);
+        }
+    }
+  else
+    {
+      if (window->progress_pulse)
+        {
+          window->progress_pulse = FALSE;
+          g_object_notify (window, "progress-pulse");
+
+          meta_topic (META_DEBUG_WINDOW_STATE,
+                      "Read XAppGtkWindow progress-pulse prop %s for %s\n",
+                      window->progress_pulse ? "TRUE" : "FALSE", window->desc);
+        }
+    }
+}
+
 static void
 complain_about_broken_client (MetaWindow    *window,
                               MetaPropValue *value,
@@ -298,13 +377,12 @@ reload_gtk_frame_extents (MetaWindow    *window,
       else
         {
           GtkBorder *extents = &window->custom_frame_extents;
-          gint scale = meta_prefs_get_ui_scale ();
 
           window->has_custom_frame_extents = TRUE;
-          extents->left   = (int)value->v.cardinal_list.cardinals[0] * scale;
-          extents->right  = (int)value->v.cardinal_list.cardinals[1] * scale;
-          extents->top    = (int)value->v.cardinal_list.cardinals[2] * scale;
-          extents->bottom = (int)value->v.cardinal_list.cardinals[3] * scale;
+          extents->left   = (int)value->v.cardinal_list.cardinals[0];
+          extents->right  = (int)value->v.cardinal_list.cardinals[1];
+          extents->top    = (int)value->v.cardinal_list.cardinals[2];
+          extents->bottom = (int)value->v.cardinal_list.cardinals[3];
         }
     }
   else
@@ -1082,10 +1160,14 @@ meta_set_normal_hints (MetaWindow *window,
 {
   int x, y, w, h;
   double minr, maxr;
+  gint ui_scale;
+
   /* Some convenience vars */
   int minw, minh, maxw, maxh;   /* min/max width/height                      */
   int basew, baseh, winc, hinc; /* base width/height, width/height increment */
 
+  ui_scale = meta_prefs_get_ui_scale ();
+
   /* Save the last ConfigureRequest, which we put here.
    * Values here set in the hints are supposed to
    * be ignored.
@@ -1184,8 +1266,8 @@ meta_set_normal_hints (MetaWindow *window,
     }
   else
     {
-      window->size_hints.width_inc = 1;
-      window->size_hints.height_inc = 1;
+      window->size_hints.width_inc = ui_scale;
+      window->size_hints.height_inc = ui_scale;
       window->size_hints.flags |= PResizeInc;
     }
 
@@ -1228,51 +1310,51 @@ meta_set_normal_hints (MetaWindow *window,
   /*** Lots of sanity checking ***/
 
   /* Verify all min & max hints are at least 1 pixel */
-  if (window->size_hints.min_width < 1)
+  if (window->size_hints.min_width < ui_scale)
     {
       /* someone is on crack */
       meta_topic (META_DEBUG_GEOMETRY,
                   "Window %s sets min width to 0, which makes no sense\n",
                   window->desc);
-      window->size_hints.min_width = 1;
+      window->size_hints.min_width = ui_scale;
     }
-  if (window->size_hints.max_width < 1)
+  if (window->size_hints.max_width < ui_scale)
     {
       /* another cracksmoker */
       meta_topic (META_DEBUG_GEOMETRY,
                   "Window %s sets max width to 0, which makes no sense\n",
                   window->desc);
-      window->size_hints.max_width = 1;
+      window->size_hints.max_width = ui_scale;
     }
-  if (window->size_hints.min_height < 1)
+  if (window->size_hints.min_height < ui_scale)
     {
       /* another cracksmoker */
       meta_topic (META_DEBUG_GEOMETRY,
                   "Window %s sets min height to 0, which makes no sense\n",
                   window->desc);
-      window->size_hints.min_height = 1;
+      window->size_hints.min_height = ui_scale;
     }
-  if (window->size_hints.max_height < 1)
+  if (window->size_hints.max_height < ui_scale)
     {
       /* another cracksmoker */
       meta_topic (META_DEBUG_GEOMETRY,
                   "Window %s sets max height to 0, which makes no sense\n",
                   window->desc);
-      window->size_hints.max_height = 1;
+      window->size_hints.max_height = ui_scale;
     }
 
   /* Verify size increment hints are at least 1 pixel */
-  if (window->size_hints.width_inc < 1)
+  if (window->size_hints.width_inc < ui_scale)
     {
       /* app authors find so many ways to smoke crack */
-      window->size_hints.width_inc = 1;
-      meta_topic (META_DEBUG_GEOMETRY, "Corrected 0 width_inc to 1\n");
+      window->size_hints.width_inc = ui_scale;
+      meta_topic (META_DEBUG_GEOMETRY, "Corrected too-small width_inc to window scale factor\n");
     }
-  if (window->size_hints.height_inc < 1)
+  if (window->size_hints.height_inc < ui_scale)
     {
       /* another cracksmoker */
-      window->size_hints.height_inc = 1;
-      meta_topic (META_DEBUG_GEOMETRY, "Corrected 0 height_inc to 1\n");
+      window->size_hints.height_inc = ui_scale;
+      meta_topic (META_DEBUG_GEOMETRY, "Corrected too-small height_inc to window scale factor\n");
     }
   /* divide by 0 cracksmokers; note that x & y in (min|max)_aspect are
    * numerator & denominator
@@ -1554,6 +1636,60 @@ reload_wm_hints (MetaWindow    *window,
   meta_window_queue (window, META_QUEUE_UPDATE_ICON | META_QUEUE_MOVE_RESIZE);
 }
 
+typedef struct
+{
+  MetaWindow *window;
+  Window transient_for_xid;
+} FindByLeaderData;
+
+static void
+find_window_by_client_leader (MetaScreen *screen,
+                              MetaWindow *window,
+                              gpointer user_data)
+{
+    FindByLeaderData *data = (FindByLeaderData *) user_data;
+
+    if (data->window != NULL)
+      {
+        return;
+      }
+
+    if (window->xclient_leader == None)
+      {
+        return;
+      }
+
+    if (window->xclient_leader == data->transient_for_xid)
+      {
+        data->window = window;
+      }
+}
+
+static MetaWindow *
+lookup_parent_by_client_leader (MetaWindow *transient,
+                                Window      xtransient_for)
+{
+    MetaWindow *parent;
+    FindByLeaderData *data;
+
+    data = g_new0 (FindByLeaderData, 1);
+
+    data->transient_for_xid = xtransient_for;
+
+    meta_screen_foreach_window (transient->screen,
+                                (MetaScreenWindowFunc) find_window_by_client_leader,
+                                data);
+
+    if (data != NULL)
+    {
+      parent = data->window;
+    }
+
+    g_free (data);
+
+    return parent;
+}
+
 static void
 reload_transient_for (MetaWindow    *window,
                       MetaPropValue *value,
@@ -1567,12 +1703,31 @@ reload_transient_for (MetaWindow    *window,
       transient_for = value->v.xwindow;
 
       parent = meta_display_lookup_x_window (window->display, transient_for);
+
       if (!parent)
         {
-          meta_warning (_("Invalid WM_TRANSIENT_FOR window 0x%lx specified "
-                          "for %s.\n"),
-                        transient_for, window->desc);
-          transient_for = None;
+          /* QT programs appear to set the transient-for hint to the program's WM_CLIENT_LEADER
+           * instead of the toplevel window's xid.  This causes muffin to throw out their transient
+           * state.  Since we know the client leader id of existing windows, we can do a quick search
+           * and match up to the correct parent so our stacking and fullscreen detection code works
+           * properly */
+
+          parent = lookup_parent_by_client_leader (window, transient_for);
+
+          if (parent)
+            {
+              transient_for = parent->xwindow;
+
+              meta_verbose ("WM_TRANSIENT_FOR was parent window 0x%lx's WM_CLIENT_LEADER. "
+                            "using the xid instead for %s.\n", transient_for, window->desc);
+            }
+          else
+            {
+              meta_warning (_("Invalid WM_TRANSIENT_FOR window 0x%lx specified "
+                              "for %s.\n"),
+                            transient_for, window->desc);
+              transient_for = None;
+            }
         }
 
       /* Make sure there is not a loop */
@@ -1803,6 +1958,9 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
     { display->atom__NET_WM_STRUT,         META_PROP_VALUE_INVALID, reload_struts,            FALSE, FALSE },
     { display->atom__NET_WM_STRUT_PARTIAL, META_PROP_VALUE_INVALID, reload_struts,            FALSE, FALSE },
     { display->atom__NET_WM_BYPASS_COMPOSITOR, META_PROP_VALUE_CARDINAL,  reload_bypass_compositor, TRUE, TRUE },
+    { display->atom__NET_WM_XAPP_ICON_NAME, META_PROP_VALUE_UTF8,     reload_theme_icon_name, TRUE,  TRUE },
+    { display->atom__NET_WM_XAPP_PROGRESS, META_PROP_VALUE_CARDINAL, reload_progress,         TRUE,  TRUE },
+    { display->atom__NET_WM_XAPP_PROGRESS_PULSE, META_PROP_VALUE_CARDINAL, reload_progress_pulse, TRUE,  TRUE },
     { 0 },
   };
 
